@@ -113,6 +113,8 @@ struct _AutoarCompressor
 
   int in_thread        : 1;
   gboolean create_top_level_directory;
+
+  gchar *passphrase;
 };
 
 G_DEFINE_TYPE (AutoarCompressor, autoar_compressor, G_TYPE_OBJECT)
@@ -166,7 +168,7 @@ autoar_compressor_get_property (GObject    *object,
       g_value_set_enum (value, self->format);
       break;
     case PROP_FILTER:
-      g_value_set_enum (value, self->format);
+      g_value_set_enum (value, self->filter);
       break;
     case PROP_CREATE_TOP_LEVEL_DIRECTORY:
       g_value_set_boolean (value, self->create_top_level_directory);
@@ -455,6 +457,23 @@ autoar_compressor_set_notify_interval (AutoarCompressor *self,
   self->notify_interval = notify_interval;
 }
 
+/**
+ * autoar_compressor_set_passphrase:
+ * @self: an #AutoarCompressor
+ * @passphrase: the archive passphrase
+ *
+ * Sets the archive passphrase. It works only with %ARCHIVE_FORMAT_ZIP.
+ **/
+void
+autoar_compressor_set_passphrase (AutoarCompressor *self,
+                                  const gchar      *passphrase)
+{
+  g_return_if_fail (AUTOAR_IS_COMPRESSOR (self));
+  g_return_if_fail (self->format == AUTOAR_FORMAT_ZIP);
+
+  self->passphrase = g_strdup (passphrase);
+}
+
 static void
 autoar_compressor_dispose (GObject *object)
 {
@@ -536,6 +555,8 @@ autoar_compressor_finalize (GObject *object)
   g_free (self->extension);
   self->extension = NULL;
 
+  g_clear_pointer (&self->passphrase, g_free);
+
   G_OBJECT_CLASS (autoar_compressor_parent_class)->finalize (object);
 }
 
@@ -1292,6 +1313,7 @@ autoar_compressor_init (AutoarCompressor *self)
   self->extension = NULL;
 
   self->in_thread = FALSE;
+  self->passphrase = NULL;
 }
 
 /**
@@ -1317,10 +1339,8 @@ autoar_compressor_new (GList        *source_files,
 
   self =
     g_object_new (AUTOAR_TYPE_COMPRESSOR,
-                  "source-files", g_list_copy_deep (source_files,
-                                                    (GCopyFunc)g_object_ref,
-                                                    NULL),
-                  "output-file", g_object_ref (output_file),
+                  "source-files", source_files,
+                  "output-file", output_file,
                   "format", format,
                   "filter", filter,
                   "create-top-level-directory", create_top_level_directory,
@@ -1373,6 +1393,20 @@ autoar_compressor_step_initialize_object (AutoarCompressor *self)
     self->error = autoar_common_g_error_new_a (self->a, NULL);
     return;
   }
+
+  if (self->passphrase != NULL && self->format == AUTOAR_FORMAT_ZIP) {
+    r = archive_write_set_options (self->a, "zip:encryption=aes256");
+    if (r != ARCHIVE_OK) {
+      self->error = autoar_common_g_error_new_a (self->a, NULL);
+      return;
+    }
+
+    r = archive_write_set_passphrase (self->a, self->passphrase);
+    if (r != ARCHIVE_OK) {
+      self->error = autoar_common_g_error_new_a (self->a, NULL);
+      return;
+    }
+  }
 }
 
 static void
