@@ -312,45 +312,6 @@ extract_test_data_free (ExtractTestData *data)
   g_free (data);
 }
 
-static gboolean
-setup_extract_tests_directory (const char *executable_path)
-{
-  g_autoptr (GFile) tests_dir = NULL;
-  gboolean found;
-
-  tests_dir = g_file_new_for_commandline_arg (executable_path);
-
-  found = FALSE;
-  while (!found && g_file_has_parent (tests_dir, NULL)) {
-    GFile *parent;
-    g_autofree gchar *parent_basename;
-
-    parent = g_file_get_parent (tests_dir);
-    parent_basename = g_file_get_basename (parent);
-
-    if (g_strcmp0 (parent_basename, TESTS_DIR_NAME) == 0) {
-      found = TRUE;
-    }
-
-    g_object_unref (tests_dir);
-    tests_dir = parent;
-  }
-
-  if (!found) {
-    g_printerr ("Tests directory not in executable path\n");
-    return FALSE;
-  }
-
-  extract_tests_dir = g_file_get_child (tests_dir, EXTRACT_TESTS_DIR_NAME);
-
-  if (!g_file_query_exists (extract_tests_dir, NULL)) {
-    g_printerr ("Extract tests directory does not exist in tests directory\n");
-    return FALSE;
-  }
-
-  return TRUE;
-}
-
 /* Asserts that all files in @included are also in @including */
 static void
 scan_directory (GFile *directory,
@@ -1241,15 +1202,18 @@ static void
 test_sanitize_absolute_path (void)
 {
   /* arextract.tar
-   * └── /arextract.txt
+   * ├── /
+   * ├── /arextract.txt
+   * └── /arextract/arextract.txt
    *
-   * 0 directories, 1 file
+   * 1 directories, 2 file
    *
    *
    * ref
-   * └── arextract.txt
+   * ├── arextract.txt
+   * └── arextract/arextract.txt
    *
-   * 0 directories, 1 file
+   * 1 directories, 2 file
    */
 
   g_autoptr (ExtractTest) extract_test = NULL;
@@ -1267,12 +1231,13 @@ test_sanitize_absolute_path (void)
   archive = g_file_get_child (extract_test->input, "arextract.tar");
 
   extractor = autoar_extractor_new (archive, extract_test->output);
+  autoar_extractor_set_output_is_dest (extractor, TRUE);
 
   data = extract_test_data_new_for_extract (extractor);
 
   autoar_extractor_start (extractor, data->cancellable);
 
-  g_assert_cmpuint (data->number_of_files, ==, 1);
+  g_assert_cmpuint (data->number_of_files, ==, 3);
   g_assert_no_error (data->error);
   g_assert_true (data->completed_signalled);
   assert_reference_and_output_match (extract_test);
@@ -1370,14 +1335,21 @@ main (int argc,
       char *argv[])
 {
   int tests_result;
-
-  if (!setup_extract_tests_directory (argv[0])) {
-    return -1;
-  }
+  g_autofree gchar *extract_tests_dir_path = NULL;
 
   g_test_init (&argc, &argv, NULL);
   g_test_set_nonfatal_assertions ();
 
+  extract_tests_dir_path = g_test_build_filename (G_TEST_DIST,
+                                                  TESTS_DIR_NAME,
+                                                  EXTRACT_TESTS_DIR_NAME,
+                                                  NULL);
+  extract_tests_dir = g_file_new_for_path (extract_tests_dir_path);
+  if (!g_file_query_exists (extract_tests_dir, NULL)) {
+    g_printerr ("Extract tests directory not found\n");
+    return -1;
+  }
+
   setup_test_suite ();
 
   tests_result = g_test_run ();
